@@ -96,7 +96,7 @@ def cancel_schedule(schedule_or_matching_id: object):
     try:
         if isinstance(schedule_or_matching_id, dict):  # expect to be scheudle
             record_id = schedule_or_matching_id.get('_id')
-            logger.debug(f"Cancel schedule by its redord_id {record_id}.")
+            logger.debug(f"Cancel schedule by its record_id {record_id}.")
             es.delete(
                 index=settings.es_index,
                 id=record_id
